@@ -1,47 +1,51 @@
 from .structs import Coin
 
-ENJ = Coin("ENJ")
-CRO = Coin("CRO")
-KNC = Coin("KNC")
-VET = Coin("VET")
-PAXG = Coin("PAXG")
-USDT = Coin("USDT")
+AAVE = Coin("AAVE")
+ADA = Coin("ADA")
 ALGO = Coin("ALGO")
 ATOM = Coin("ATOM")
-COMP = Coin("COMP")
-UNI = Coin("UNI")
-AAVE = Coin("AAVE")
-WBTC = Coin("WBTC")
-XRP = Coin("XRP")
-XLM = Coin("XLM")
-LINK = Coin("LINK")
-YFI = Coin("YFI")
-QTUM = Coin("QTUM")
-XTZ = Coin("XTZ")
-MANA = Coin("MANA")
-BCH = Coin("BCH")
-EOS = Coin("EOS")
-OMG = Coin("OMG")
 BAND = Coin("BAND")
-DAI = Coin("DAI")
-BTC = Coin("BTC")
-ETC = Coin("ETC")
-MKR = Coin("MKR")
 BAT = Coin("BAT")
+BCH = Coin("BCH")
+BNT = Coin("BNT")
+BTC = Coin("BTC")
 CELR = Coin("CELR")
-ETH = Coin("ETH")
-MCO = Coin("MCO")
-NEO = Coin("NEO")
-LTC = Coin("LTC")
-EGLD = Coin("EGLD")
-USDC = Coin("USDC")
-ADA = Coin("ADA")
-ICX = Coin("ICX")
-DOT = Coin("DOT")
-REN = Coin("REN")
-ONT = Coin("ONT")
+COMP = Coin("COMP")
+CRO = Coin("CRO")
 CRV = Coin("CRV")
+DAI = Coin("DAI")
+DOT = Coin("DOT")
+EGLD = Coin("EGLD")
+ENJ = Coin("ENJ")
+EOS = Coin("EOS")
+ETC = Coin("ETC")
+ETH = Coin("ETH")
+GRT = Coin("GRT")
+ICX = Coin("ICX")
+KNC = Coin("KNC")
+KSM = Coin("KSM")
+LINK = Coin("LINK")
 LRC = Coin("LRC")
+LTC = Coin("LTC")
+MANA = Coin("MANA")
+MCO = Coin("MCO")
+MKR = Coin("MKR")
+NEO = Coin("NEO")
+OMG = Coin("OMG")
+ONT = Coin("ONT")
+PAXG = Coin("PAXG")
+QTUM = Coin("QTUM")
+REN = Coin("REN")
+UNI = Coin("UNI")
+USDC = Coin("USDC")
+USDT = Coin("USDT")
+VET = Coin("VET")
+WBTC = Coin("WBTC")
+XLM = Coin("XLM")
+XRP = Coin("XRP")
+XTZ = Coin("XTZ")
+YFI = Coin("YFI")
+ZIL = Coin("ZIL")
 
 
 def all():
